from tornado.web import RequestHandler, asynchronous, HTTPError
from tornado.httpclient import AsyncHTTPClient
from base.django_handler_mixin import DjangoHandlerMixin
from django.conf import settings

ALLOWED_DOMAINS = {
    'sowiportbeta.gesis.org':
        'api_key=' + settings.SOWIPORT_KEY if settings.SOWIPORT_KEY else True,
    'xisbn.worldcat.org': False,
    'www.worldcat.org':
        'wskey=' + settings.WORLDCAT_KEY if settings.WORLDCAT_KEY else True
}


class Proxy(DjangoHandlerMixin, RequestHandler):
    @asynchronous
    def get(self, url):
        user = self.get_current_user()
        domain = url.split('/')[2]
        if domain not in ALLOWED_DOMAINS or not user.is_authenticated():
            self.set_status(401)
            self.finish()
            return
        query = self.request.query
        api_key = ALLOWED_DOMAINS[domain]
        if api_key is not False:
            if api_key is True:
                # There is an API-key, but it is not defined. Return empty.
                self.set_status(200)
                self.finish()
                return
            if query:
                query = query + '&' + api_key
            else:
                query = api_key
            print query
        if query:
            url += '?' + query
        http = AsyncHTTPClient()
        http.fetch(
            url,
            method='GET',
            callback=self.on_response
        )

    # The response is asynchronous so that the getting of the data from the
    # remote server doesn't block the server connection.
    def on_response(self, response):
        if response.error:
            raise HTTPError(500)
        self.write(response.body)
        self.finish()



import os
from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='fiduswriter-citation-api-import',
    version='3.1.12',
    packages=find_packages(),
    include_package_data=True,
    license='AGPL License',
    description='A Fidus Writer plugin to import citations via API.',
    long_description=README,
    url='https://www.github.org/fiduswriter/fiduswriter-citation-api-import',
    author='Johannes Wilm',
    author_email='johannes@fiduswriter.org',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU Affero General Public License v3',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
